;-- AUTO-EXECUTE SECTION:
;; #NoTrayIcon 	; prevent the showing of a tray icon for this script
#SingleInstance force
				; ensure we only run 1 copy of this file.
#NoEnv         	; Recommended for performance and compatibility with future AutoHotkey releases.
#Warn          	; Enable warnings to assist with detecting common errors.
SendMode Input 	; Recommended for new scripts due to its superior speed and reliability.
SetWorkingDir %A_ScriptDir%
				; makes the script unconditionally use its own folder as working directory.
; show a (re)load notification:
  SplashTextOn, 200, 20, Autohotkey, Reloaded %A_ScriptName%
  Sleep, 400
  SplashTextOff
return         	; this is the end of the AUTO-EXECUTE SECTION
;-------------------------------------------------------------------------------

;-- README ---------------------------------------------------------------------
; This AHK file re-maps a Qwerty keyboard into a Colemak keyboard. This is especially useful when 
; the local computer is limited by corporate security policies to disallow installation of custom 
; software. AHK can be run as a portable app, and this script then remaps the existing keyboard.
; 
; German Umlauts can easily be typed using the conventional umlaut "dead key" (rightmost key in the 
; top row).
; 
; CREATED BY: ------------------------------------------------------------------
; Torben Gundtofte-Bruun, torben@g-b.dk, http://torben.g-b.dk/+
; 
; FEATURES: --------------------------------------------------------------------
; * Toggle remapping on/off by hitting both Ctrl keys. There's no indicator but you'll notice once you start typing...!
; * Additional Ctrl-shortcuts can be added as needed (e.g. for "Save").
; * At present, the script assumes a Danish (DK) input layout and includes Danish characters in the output. This is fairly easy to change.
; 
; HISTORY: ---------------------------------------------------------------------
; 2015-05-08  Created by Torben Gundtofte-Bruun.
; 
; WISH LIST: -------------------------------------------------------------------
; * 20150508 Implement the "Tarmak" approach for easier learning!
; * Some kind of indicator to show current layout.
; 
;-- LEGEND ---------------------------------------------------------------------
; # = Win
; ^ = Ctrl
; ! = Alt
; + = Shift
; <^ = Left Ctrl only
; >! = Right Alt only = AltGr
; $F1 = function key
; ~ = pass the key on to the OS (but also use it in AHK). Normally blocked.
; {enter}, {tab}, etc. = keystroke
; Starting with :*C: makes the trigger case sensitive.
;-------------------------------------------------------------------------------

Lctrl & RCtrl::  ; hit both CTRL keys to toggle Colemak on or off:
Rctrl & LCtrl::  ; (regardless which CTRL was pressed first)
suspend			 ; This needs to be first, to keep the hotkey alive when the rest of the script is suspended.
SplashTextOn, 200, 20, Colemak, Colemak toggled.
Sleep, 400
SplashTextOff
return

"Win+c" (re)loads the Colemak mapping (excluded from above because I haven't switched to that yet)
#c::Run C:\LocalData\WZBGDT\SVN\Torben\Work\Tools\Autohotkey\colemak-dk.ahk

;-- number row -----------------------------------------------------------------
; no change = same as in Qwerty.

;-- top row --------------------------------------------------------------------
;q::q ; no change
;w::w ; no change
e::f
r::p
t::g
y::j
u::l
i::u
o::y
:*C:p::{ASC 0230} ; æ
:*C:P::{ASC 0198} ; Æ
;SC01A::å ; no change
;¨::¨ ; no change

;-- home row -------------------------------------------------------------------
;a::a ; no change
s::r
d::s
f::t
g::d
;h::h ; no change
j::n
k::e
l::i
SC027::o
;SC028::ø ; no change
;SC02B::' ; no change

;-- bottom row -----------------------------------------------------------------
; SC056::send {ASC 0248} ; no change
;+SC056::send {ASC 0216} ; no change
;z::z ; no change
;x::x ; no change
;c::c ; no change
;v::v ; no change
;b::b ; no change
n::k
;m::m ; no change
;,::, ; no change
;.::. ; no change
;-::- ; no change

;-------------------------------------------------------------------------------
;-- cut, copy, paste, etc.
; No change needed because key combos remain mapped to the layout :-)
; Notice: all other combos like Ctrl+B also don't move!!


;-- debugging stuff ------------------------------------------------------------
#K::KeyHistory

